@@ -373,6 +373,13 @@ class Sequential():
                         if live_stats == 2 or live_stats == -1:
                             axs2.cla()
                             
+                            if len(self.train_inputs[0,:]) <= 2:
+                                X_set, y_set = self.train_inputs, self.train_targets
+                                X1, X2 = np.meshgrid(np.arange(start = X_set[:, 0].min() - 1, stop = X_set[:, 0].max() + 1, step = 0.01),
+                                                     np.arange(start = X_set[:, 1].min() - 1, stop = X_set[:, 1].max() + 1, step = 0.01))
+                                axs2.contourf(X1, X2, self.predict(np.array([X1.ravel(), X2.ravel()]).T).reshape(X1.shape),
+                                             alpha = 0.2, cmap = "coolwarm")
+                                
                             axs2.scatter(self.train_inputs[:,0], self.train_inputs[:,1], c=self.train_outputs[:,:], cmap="coolwarm", alpha=1)
                             
                             figure2.canvas.draw()
@@ -419,6 +426,13 @@ class Sequential():
                         if live_stats == 2 or live_stats == -1:
                             axs2.cla()
                             
+                            if len(self.train_inputs[0,:]) <= 2:
+                                X_set, y_set = self.train_inputs, self.train_targets
+                                X1, X2 = np.meshgrid(np.arange(start = X_set[:, 0].min() - 1, stop = X_set[:, 0].max() + 1, step = 0.01),
+                                                     np.arange(start = X_set[:, 1].min() - 1, stop = X_set[:, 1].max() + 1, step = 0.01))
+                                axs2.contourf(X1, X2, self.predict(np.array([X1.ravel(), X2.ravel()]).T).reshape(X1.shape),
+                                             alpha = 0.2, cmap = "coolwarm")
+                            
                             axs2.scatter(self.train_inputs[:,0], self.train_inputs[:,1], c=self.train_outputs[:,:], cmap="coolwarm", alpha=1)
                             
                             figure2.canvas.draw()
